@@ -59,113 +59,113 @@ module.exports = grammar({
 		// Assign a rule to all tokenized statements and functions
 		// These are taken from Table H-3 in Ref. 2
 
-			end_tok: $ => /E *N *D/,
-			for_tok: $ => /F *O *R/,
-			next_tok: $ => /N *E *X *T/,
-			data_tok: $ => /D *A *T *A/,
-			input_tok: $ => /I *N *P *U *T/,
-			del_tok: $ => /D *E *L/,
-			dim_tok: $ => /D *I *M/,
-			read_tok: $ => /R *E *A *D/,
-			gr_tok: $ => /G *R/,
-			text_tok: $ => /T *E *X *T/,
-			prn_tok: $ => /P *R *#/,
-			inn_tok: $ => /I *N *#/,
-			call_tok: $ => /C *A *L *L/,
-			plot_tok: $ => /P *L *O *T/,
-			hlin_tok: $ => /H *L *I *N/,
-			vlin_tok: $ => /V *L *I *N/,
-			hgr2_tok: $ => /H *G *R *2/,
-			hgr_tok: $ => /H *G *R/,
-			hcoloreq_tok: $ => /H *C *O *L *O *R *=/,
-			hplot_tok: $ => /H *P *L *O *T/,
-			draw_tok: $ => /D *R *A *W/,
-			xdraw_tok: $ => /X *D *R *A *W/,
-			htab_tok: $ => /H *T *A *B/,
-			home_tok: $ => /H *O *M *E/,
-			roteq_tok: $ => /R *O *T *=/,
-			scaleeq_tok: $ => /S *C *A *L *E *=/,
-			shload_tok: $ => /S *H *L *O *A *D/,
-			trace_tok: $ => /T *R *A *C *E/,
-			notrace_tok: $ => /N *O *T *R *A *C *E/,
-			normal_tok: $ => /N *O *R *M *A *L/,
-			inverse_tok: $ => /I *N *V *E *R *S *E/,
-			flash_tok: $ => /F *L *A *S *H/,
-			coloreq_tok: $ => /C *O *L *O *R *=/,
-			pop_tok: $ => /P *O *P/,
-			vtab_tok: $ => /V *T *A *B/,
-			himem_tok: $ => /H *I *M *E *M *:/,
-			lomem_tok: $ => /L *O *M *E *M *:/,
-			onerr_tok: $ => /O *N *E *R *R/,
-			resume_tok: $ => /R *E *S *U *M *E/,
-			recall_tok: $ => /R *E *C *A *L *L/,
-			store_tok: $ => /S *T *O *R *E/,
-			speedeq_tok: $ => /S *P *E *E *D *=/,
-			let_tok: $ => /L *E *T/,
-			goto_tok: $ => /G *O *T *O/,
-			run_tok: $ => /R *U *N/,
-			if_tok: $ => /I *F/,
-			restore_tok: $ => /R *E *S *T *O *R *E/,
+			end_tok: $ => /[Ee] *[Nn] *[Dd]/,
+			for_tok: $ => /[Ff] *[Oo] *[Rr]/,
+			next_tok: $ => /[Nn] *[Ee] *[Xx] *[Tt]/,
+			data_tok: $ => /[Dd] *[Aa] *[Tt] *[Aa]/,
+			input_tok: $ => /[Ii] *[Nn] *[Pp] *[Uu] *[Tt]/,
+			del_tok: $ => /[Dd] *[Ee] *[Ll]/,
+			dim_tok: $ => /[Dd] *[Ii] *[Mm]/,
+			read_tok: $ => /[Rr] *[Ee] *[Aa] *[Dd]/,
+			gr_tok: $ => /[Gg] *[Rr]/,
+			text_tok: $ => /[Tt] *[Ee] *[Xx] *[Tt]/,
+			prn_tok: $ => /[Pp] *[Rr] *[##]/,
+			inn_tok: $ => /[Ii] *[Nn] *[##]/,
+			call_tok: $ => /[Cc] *[Aa] *[Ll] *[Ll]/,
+			plot_tok: $ => /[Pp] *[Ll] *[Oo] *[Tt]/,
+			hlin_tok: $ => /[Hh] *[Ll] *[Ii] *[Nn]/,
+			vlin_tok: $ => /[Vv] *[Ll] *[Ii] *[Nn]/,
+			hgr2_tok: $ => /[Hh] *[Gg] *[Rr] *[22]/,
+			hgr_tok: $ => /[Hh] *[Gg] *[Rr]/,
+			hcoloreq_tok: $ => /[Hh] *[Cc] *[Oo] *[Ll] *[Oo] *[Rr] *[==]/,
+			hplot_tok: $ => /[Hh] *[Pp] *[Ll] *[Oo] *[Tt]/,
+			draw_tok: $ => /[Dd] *[Rr] *[Aa] *[Ww]/,
+			xdraw_tok: $ => /[Xx] *[Dd] *[Rr] *[Aa] *[Ww]/,
+			htab_tok: $ => /[Hh] *[Tt] *[Aa] *[Bb]/,
+			home_tok: $ => /[Hh] *[Oo] *[Mm] *[Ee]/,
+			roteq_tok: $ => /[Rr] *[Oo] *[Tt] *[==]/,
+			scaleeq_tok: $ => /[Ss] *[Cc] *[Aa] *[Ll] *[Ee] *[==]/,
+			shload_tok: $ => /[Ss] *[Hh] *[Ll] *[Oo] *[Aa] *[Dd]/,
+			trace_tok: $ => /[Tt] *[Rr] *[Aa] *[Cc] *[Ee]/,
+			notrace_tok: $ => /[Nn] *[Oo] *[Tt] *[Rr] *[Aa] *[Cc] *[Ee]/,
+			normal_tok: $ => /[Nn] *[Oo] *[Rr] *[Mm] *[Aa] *[Ll]/,
+			inverse_tok: $ => /[Ii] *[Nn] *[Vv] *[Ee] *[Rr] *[Ss] *[Ee]/,
+			flash_tok: $ => /[Ff] *[Ll] *[Aa] *[Ss] *[Hh]/,
+			coloreq_tok: $ => /[Cc] *[Oo] *[Ll] *[Oo] *[Rr] *[==]/,
+			pop_tok: $ => /[Pp] *[Oo] *[Pp]/,
+			vtab_tok: $ => /[Vv] *[Tt] *[Aa] *[Bb]/,
+			himem_tok: $ => /[Hh] *[Ii] *[Mm] *[Ee] *[Mm] *[::]/,
+			lomem_tok: $ => /[Ll] *[Oo] *[Mm] *[Ee] *[Mm] *[::]/,
+			onerr_tok: $ => /[Oo] *[Nn] *[Ee] *[Rr] *[Rr]/,
+			resume_tok: $ => /[Rr] *[Ee] *[Ss] *[Uu] *[Mm] *[Ee]/,
+			recall_tok: $ => /[Rr] *[Ee] *[Cc] *[Aa] *[Ll] *[Ll]/,
+			store_tok: $ => /[Ss] *[Tt] *[Oo] *[Rr] *[Ee]/,
+			speedeq_tok: $ => /[Ss] *[Pp] *[Ee] *[Ee] *[Dd] *[==]/,
+			let_tok: $ => /[Ll] *[Ee] *[Tt]/,
+			goto_tok: $ => /[Gg] *[Oo] *[Tt] *[Oo]/,
+			run_tok: $ => /[Rr] *[Uu] *[Nn]/,
+			if_tok: $ => /[Ii] *[Ff]/,
+			restore_tok: $ => /[Rr] *[Ee] *[Ss] *[Tt] *[Oo] *[Rr] *[Ee]/,
 			amp_tok: $ => '&',
-			gosub_tok: $ => /G *O *S *U *B/,
-			return_tok: $ => /R *E *T *U *R *N/,
-			rem_tok: $ => /R *E *M/,
-			stop_tok: $ => /S *T *O *P/,
-			on_tok: $ => /O *N/,
-			wait_tok: $ => /W *A *I *T/,
-			load_tok: $ => /L *O *A *D/,
-			save_tok: $ => /S *A *V *E/,
-			def_tok: $ => /D *E *F/,
-			poke_tok: $ => /P *O *K *E/,
-			print_tok: $ => /P *R *I *N *T/,
-			cont_tok: $ => /C *O *N *T/,
-			list_tok: $ => /L *I *S *T/,
-			clear_tok: $ => /C *L *E *A *R/,
-			get_tok: $ => /G *E *T/,
-			new_tok: $ => /N *E *W/,
-			tabp_tok: $ => /T *A *B *\(/,
-			to_tok: $ => /T *O/,
-			fn_tok: $ => /F *N/,
-			spcp_tok: $ => /S *P *C *\(/,
-			then_tok: $ => /T *H *E *N/,
-			at_tok: $ => /A *T/,
-			not_tok: $ => /N *O *T/,
-			step_tok: $ => /S *T *E *P/,
+			gosub_tok: $ => /[Gg] *[Oo] *[Ss] *[Uu] *[Bb]/,
+			return_tok: $ => /[Rr] *[Ee] *[Tt] *[Uu] *[Rr] *[Nn]/,
+			rem_tok: $ => /[Rr] *[Ee] *[Mm]/,
+			stop_tok: $ => /[Ss] *[Tt] *[Oo] *[Pp]/,
+			on_tok: $ => /[Oo] *[Nn]/,
+			wait_tok: $ => /[Ww] *[Aa] *[Ii] *[Tt]/,
+			load_tok: $ => /[Ll] *[Oo] *[Aa] *[Dd]/,
+			save_tok: $ => /[Ss] *[Aa] *[Vv] *[Ee]/,
+			def_tok: $ => /[Dd] *[Ee] *[Ff]/,
+			poke_tok: $ => /[Pp] *[Oo] *[Kk] *[Ee]/,
+			print_tok: $ => /[Pp] *[Rr] *[Ii] *[Nn] *[Tt]/,
+			cont_tok: $ => /[Cc] *[Oo] *[Nn] *[Tt]/,
+			list_tok: $ => /[Ll] *[Ii] *[Ss] *[Tt]/,
+			clear_tok: $ => /[Cc] *[Ll] *[Ee] *[Aa] *[Rr]/,
+			get_tok: $ => /[Gg] *[Ee] *[Tt]/,
+			new_tok: $ => /[Nn] *[Ee] *[Ww]/,
+			tabp_tok: $ => /[Tt] *[Aa] *[Bb] *[\(\(]/,
+			to_tok: $ => /[Tt] *[Oo]/,
+			fn_tok: $ => /[Ff] *[Nn]/,
+			spcp_tok: $ => /[Ss] *[Pp] *[Cc] *[\(\(]/,
+			then_tok: $ => /[Tt] *[Hh] *[Ee] *[Nn]/,
+			at_tok: $ => /[Aa] *[Tt]/,
+			not_tok: $ => /[Nn] *[Oo] *[Tt]/,
+			step_tok: $ => /[Ss] *[Tt] *[Ee] *[Pp]/,
 			plus_tok: $ => '+',
 			minus_tok: $ => '-',
 			times_tok: $ => '*',
 			div_tok: $ => '/',
 			pow_tok: $ => '^',
-			and_tok: $ => /A *N *D/,
-			or_tok: $ => /O *R/,
+			and_tok: $ => /[Aa] *[Nn] *[Dd]/,
+			or_tok: $ => /[Oo] *[Rr]/,
 			gtr_tok: $ => '>',
 			eq_tok: $ => '=',
 			less_tok: $ => '<',
-			sgn_tok: $ => /S *G *N/,
-			int_tok: $ => /I *N *T/,
-			abs_tok: $ => /A *B *S/,
-			usr_tok: $ => /U *S *R/,
-			fre_tok: $ => /F *R *E/,
-			scrnp_tok: $ => /S *C *R *N *\(/,
-			pdl_tok: $ => /P *D *L/,
-			pos_tok: $ => /P *O *S/,
-			sqr_tok: $ => /S *Q *R/,
-			rnd_tok: $ => /R *N *D/,
-			log_tok: $ => /L *O *G/,
-			exp_tok: $ => /E *X *P/,
-			cos_tok: $ => /C *O *S/,
-			sin_tok: $ => /S *I *N/,
-			tan_tok: $ => /T *A *N/,
+			sgn_tok: $ => /[Ss] *[Gg] *[Nn]/,
+			int_tok: $ => /[Ii] *[Nn] *[Tt]/,
+			abs_tok: $ => /[Aa] *[Bb] *[Ss]/,
+			usr_tok: $ => /[Uu] *[Ss] *[Rr]/,
+			fre_tok: $ => /[Ff] *[Rr] *[Ee]/,
+			scrnp_tok: $ => /[Ss] *[Cc] *[Rr] *[Nn] *[\(\(]/,
+			pdl_tok: $ => /[Pp] *[Dd] *[Ll]/,
+			pos_tok: $ => /[Pp] *[Oo] *[Ss]/,
+			sqr_tok: $ => /[Ss] *[Qq] *[Rr]/,
+			rnd_tok: $ => /[Rr] *[Nn] *[Dd]/,
+			log_tok: $ => /[Ll] *[Oo] *[Gg]/,
+			exp_tok: $ => /[Ee] *[Xx] *[Pp]/,
+			cos_tok: $ => /[Cc] *[Oo] *[Ss]/,
+			sin_tok: $ => /[Ss] *[Ii] *[Nn]/,
+			tan_tok: $ => /[Tt] *[Aa] *[Nn]/,
 			atn_tok: $ => /A *TN/,
-			peek_tok: $ => /P *E *E *K/,
-			len_tok: $ => /L *E *N/,
-			str_tok: $ => /S *T *R *\$/,
-			val_tok: $ => /V *A *L/,
-			asc_tok: $ => /A *S *C/,
-			chr_tok: $ => /C *H *R *\$/,
-			left_tok: $ => /L *E *F *T *\$/,
-			right_tok: $ => /R *I *G *H *T *\$/,
-			mid_tok: $ => /M *I *D *\$/,
+			peek_tok: $ => /[Pp] *[Ee] *[Ee] *[Kk]/,
+			len_tok: $ => /[Ll] *[Ee] *[Nn]/,
+			str_tok: $ => /[Ss] *[Tt] *[Rr] *[\$\$]/,
+			val_tok: $ => /[Vv] *[Aa] *[Ll]/,
+			asc_tok: $ => /[Aa] *[Ss] *[Cc]/,
+			chr_tok: $ => /[Cc] *[Hh] *[Rr] *[\$\$]/,
+			left_tok: $ => /[Ll] *[Ee] *[Ff] *[Tt] *[\$\$]/,
+			right_tok: $ => /[Rr] *[Ii] *[Gg] *[Hh] *[Tt] *[\$\$]/,
+			mid_tok: $ => /[Mm] *[Ii] *[Dd] *[\$\$]/,
 
 
 		// Statements from Appendix A
